@@ -11,7 +11,7 @@ from .conftest import gdal_version
 def mock_wheel(tmpdir):
     """A fake rasterio wheel"""
     moduledir = tmpdir.mkdir("rasterio")
-    moduledir.ensure("__init__,py")
+    moduledir.ensure("__init__.py")
     moduledir.ensure("_env.py")
     moduledir.ensure("gdal_data/pcs.csv")
     moduledir.ensure("proj_data/epsg")
@@ -60,7 +60,7 @@ def test_search_prefix_gdal_data_failure(tmpdir):
 def test_search_prefix_gdal_data(mock_fhs):
     """Find GDAL data under prefix"""
     finder = GDALDataFinder()
-    assert finder.search_prefix(str(mock_fhs)) == str(mock_fhs.join("share/gdal"))
+    assert finder.search_prefix(str(mock_fhs)) == str(mock_fhs.join("share").join("gdal"))
 
 
 def test_search_debian_gdal_data_failure(tmpdir):
@@ -72,7 +72,7 @@ def test_search_debian_gdal_data_failure(tmpdir):
 def test_search_debian_gdal_data(mock_debian):
     """Find GDAL data under Debian locations"""
     finder = GDALDataFinder()
-    assert finder.search_debian(str(mock_debian)) == str(mock_debian.join("share/gdal/{}".format(str(gdal_version))))
+    assert finder.search_debian(str(mock_debian)) == str(mock_debian.join("share").join("gdal").join("{}".format(str(gdal_version))))
 
 
 def test_search_gdal_data_wheel(mock_wheel):
@@ -82,13 +82,13 @@ def test_search_gdal_data_wheel(mock_wheel):
 
 def test_search_gdal_data_fhs(mock_fhs):
     finder = GDALDataFinder()
-    assert finder.search(str(mock_fhs)) == str(mock_fhs.join("share/gdal"))
+    assert finder.search(str(mock_fhs)) == str(mock_fhs.join("share").join("gdal"))
 
 
 def test_search_gdal_data_debian(mock_debian):
     """Find GDAL data under Debian locations"""
     finder = GDALDataFinder()
-    assert finder.search(str(mock_debian)) == str(mock_debian.join("share/gdal/{}".format(str(gdal_version))))
+    assert finder.search(str(mock_debian)) == str(mock_debian.join("share").join("gdal").join("{}".format(str(gdal_version))))
 
 
 def test_search_wheel_proj_data_failure(tmpdir):
@@ -112,7 +112,7 @@ def test_search_prefix_proj_data_failure(tmpdir):
 def test_search_prefix_proj_data(mock_fhs):
     """Find GDAL data under prefix"""
     finder = PROJDataFinder()
-    assert finder.search_prefix(str(mock_fhs)) == str(mock_fhs.join("share/proj"))
+    assert finder.search_prefix(str(mock_fhs)) == str(mock_fhs.join("share").join("proj"))
 
 
 def test_search_proj_data_wheel(mock_wheel):
@@ -122,4 +122,4 @@ def test_search_proj_data_wheel(mock_wheel):
 
 def test_search_proj_data_fhs(mock_fhs):
     finder = PROJDataFinder()
-    assert finder.search(str(mock_fhs)) == str(mock_fhs.join("share/proj"))
+    assert finder.search(str(mock_fhs)) == str(mock_fhs.join("share").join("proj"))
